---
title: Plugin
---

### Plugin

This section will go over how to use the plugin that comes with the Navigation module.


#### menu

The `menu` function let's you generate navigation structure based on the specified navigation menu.

The returned plugin criteria will render the resulting navigation automatically using `__toString()` if you do not explicitly call `render()`.

###### Returns: `\Anomaly\Streams\Platform\Addon\Plugin\PluginCriteria`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$root

</td>

<td>

false

</td>

<td>

mixed

</td>

<td>

none

</td>

<td>

The id, instance, or path of the root navigation link.

</td>

</tr>

</tbody>

</table>

###### Twig

    {{ menu()|raw }}

    {# Showing child navigation #}
    {{ menu('about')
        .linkAttributesDropdown({'data-toggle': 'dropdown'})
        .listClass('nav navbar-nav navbar-right')
        .childListClass('dropdown-menu')
        .render()|raw }}


##### Available Options

The `menu` function uses the plugin criteria to allow you to configure options for the resulting navigation.

Options are defined by chaining together `camelCase` methods:

    {{ menu().optionOne('example')|raw }} // Results in option_one = example

So to define `dropdown_class` for example you would do this:

    {{ menu().dropdownClass('dropdown')|raw }}

> Defining criteria options this way is standard throughout Pyro!{.tip}

###### Options

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

view

</td>

<td>

false

</td>

<td>

anomaly.module.navigation::links

</td>

<td>

The base view to render the navigation from.

</td>

</tr>

<tr>

<td>

macro

</td>

<td>

false

</td>

<td>

anomaly.module.navigation::macro

</td>

<td>

The macro to use for rendering the navigation.

</td>

</tr>

<tr>

<td>

depth

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The maximum depth of the navigation.

</td>

</tr>

<tr>

<td>

list_tag

</td>

<td>

false

</td>

<td>

ul

</td>

<td>

The list tag to use.

</td>

</tr>

<tr>

<td>

list_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The list class to use.

</td>

</tr>

<tr>

<td>

item_tag

</td>

<td>

false

</td>

<td>

li

</td>

<td>

The list item tag to use.

</td>

</tr>

<tr>

<td>

item_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The list item class to use.

</td>

</tr>

<tr>

<td>

dropdown_class

</td>

<td>

false

</td>

<td>

dropdown

</td>

<td>

The CSS class for links containing child links.

</td>

</tr>

<tr>

<td>

active_class

</td>

<td>

false

</td>

<td>

active

</td>

<td>

The CSS class for links that are selected or whose child link is selected.

</td>

</tr>

<tr>

<td>

selected_class

</td>

<td>

false

</td>

<td>

current

</td>

<td>

The CSS class for the currently selected navigation link.

</td>

</tr>

<tr>

<td>

link_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The CSS class to use for links.

</td>

</tr>

<tr>

<td>

link_attributes

</td>

<td>

false

</td>

<td>

[]

</td>

<td>

An array of key value html attributes for links.

</td>

</tr>

<tr>

<td>

link_attributes_dropdown

</td>

<td>

false

</td>

<td>

[]

</td>

<td>

An array of key value html attributes for links that have a dropdown.

</td>

</tr>

<tr>

<td>

child_list_tag

</td>

<td>

false

</td>

<td>

list_tag

</td>

<td>

The list tag for child lists.

</td>

</tr>

<tr>

<td>

child_list_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The list class for child lists.

</td>

</tr>

<tr>

<td>

dropdown_toggle

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The dropdown toggle tag to use in the case a dropdown toggle is desired.

</td>

</tr>

<tr>

<td>

dropdown_toggle_class

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The dropdown toggle class to use in the case a dropdown toggle is desired.

</td>

</tr>

<tr>

<td>

dropdown_toggle_attributes

</td>

<td>

false

</td>

<td>

[]

</td>

<td>

An array of key value html attributes for the dropdown toggle.

</td>

</tr>

<tr>

<td>

dropdown_toggle_text

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The text or HTML to display inside the dropdown toggle.

</td>

</tr>

</tbody>

</table>


#### links

The `links` function returns the links in a specified menu.

To return the collection of links use the `get()` trigger on the plugin criteria (see example below).

###### Returns: `\Anomaly\NavigationModule\Link\LinkCollection`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$menu

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The slug of the menu to return links for.

</td>

</tr>

</tbody>

</table>

###### Twig

    {% for link in links('footer').get() %}
    <p>
        <a href="{{ link.url }}" target="{{ link.target.key }}">{{ link.title }}</a>
    </p>
    {% endfor %}


##### Available Options

The `links` function uses the plugin criteria to allow you to configure options for the resulting navigation.

Options are defined by chaining together `camelCase` methods:

    {{ links().optionOne('example')|raw }} // Results in option_one = example

So to define `dropdown_class` for example you would do this:

    {{ links().dropdownClass('dropdown')|raw }}

> Defining criteria options this way is standard throughout Pyro!{.tip}

###### Options

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

root

</td>

<td>

false

</td>

<td>

none

</td>

<td>

The id or path of the root link to start navigation from.

</td>

</tr>

</tbody>

</table>
